@@ -7,10 +7,10 @@
 #define ADIOSCONFIG_H_
 
 /* ADIOS Version Information */
-#define ADIOS2_VERSION_STR   "2.8.0"
+#define ADIOS2_VERSION_STR   "2.8.3"
 #define ADIOS2_VERSION_MAJOR 2
 #define ADIOS2_VERSION_MINOR 8
-#define ADIOS2_VERSION_PATCH 0
+#define ADIOS2_VERSION_PATCH 3
 /* #undef ADIOS2_VERSION_TWEAK */
 
 /*
@@ -18,11 +18,11 @@
  *
  * Compiler:
  *   C: /usr/lib/distcc/bin/cc
- *     Id: GNU 11.2.0
+ *     Id: GNU 12.1.0
  *   CXX: /usr/lib/distcc/bin/c++
- *     Id: GNU 11.2.0
+ *     Id: GNU 12.1.0
  *   Fortran: /usr/lib/distcc/bin/c++
- *     Id: GNU 11.2.0
+ *     Id: GNU 12.1.0
  */
 
 /* Everything between here and the note below is programatically generated */
@@ -80,7 +80,7 @@
 #define ADIOS2_HAVE_SZ
 
 /* CMake Option: ADIOS_USE_ZFP=OFF */
-#define ADIOS2_HAVE_ZFP
+/* #undef ADIOS2_HAVE_ZFP */
 
 /* CMake Option: ADIOS_USE_DAOS=OFF */
 /* #undef ADIOS2_HAVE_DAOS */
