@@ -27,6 +27,7 @@ class Query; // friend
 namespace core
 {
 class Engine; // private implementation
+
 }
 /// \endcond
 
@@ -62,6 +63,12 @@ public:
      */
     std::string Type() const;
 
+    /**
+     * Returns the Mode used at Open for current Engine
+     * @return
+     */
+    Mode OpenMode() const;
+
     /**
      * Begin a logical adios2 step, overloaded version with timeoutSeconds = 0
      * and mode = Read
@@ -94,22 +101,24 @@ public:
      * Put signature that provides access to the internal engine buffer for a
      * pre-allocated variable including a fill value. Returns a fixed size Span
      * (based on C++20 std::span) so applications can populate data value after
-     * this Put. Requires a call to PerformPuts, EndStep, or Close to extract
-     * the Min/Max bounds.
+     * this Put and before PerformPuts/EndStep. Requires a call to PerformPuts,
+     * EndStep, or Close to extract the Min/Max bounds.
      * @param variable input variable
-     * @param bufferID if engine has multiple buffers, input 0 when this
-     * information is not known
+     * @param initialize bool flag indicating if allocated memory should be
+     * initialized with the provided value. Some engines (BP3/BP4) may
+     * initialize the allocated memory anyway to zero if this flag is false.
      * @param value provide an initial fill value
      * @return span to variable data in engine internal buffer
      */
     template <class T>
-    typename Variable<T>::Span Put(Variable<T> variable, const size_t bufferID,
+    typename Variable<T>::Span Put(Variable<T> variable, const bool initialize,
                                    const T &value);
 
     /**
      * Put signature that provides access to an internal engine buffer (decided
-     * by the engine) for a pre-allocated variable with the default fill value
-     * T().
+     * by the engine) for a pre-allocated variable. Allocated buffer may or may
+     * not be initialized to zero by the engine (e.g. BP3/BP4 does, BP5 does
+     * not).
      * @param variable input variable
      * @return span to variable data in engine internal buffer
      */
@@ -182,9 +191,16 @@ public:
     void Put(const std::string &variableName, const T &datum,
              const Mode launch = Mode::Deferred);
 
-    /** Perform all Put calls in Deferred mode up to this point */
+    /** Perform all Put calls in Deferred mode up to this point.  Specifically,
+     * this causes Deferred data to be copied into ADIOS internal buffers as if
+     * the Put had been done in Sync mode. */
     void PerformPuts();
 
+    /** Write already-Put() array data to disk.  If supported by the engine,
+     * this may relieve memory pressure by clearing ADIOS buffers.  It is a
+     * collective call and can only be called between Begin/EndStep pairs. */
+    void PerformDataWrite();
+
     /**
      * Get data associated with a Variable from the Engine
      * @param variable contains variable metadata information
@@ -445,8 +461,7 @@ private:
 #define declare_template_instantiation(T)                                      \
                                                                                \
     extern template typename Variable<T>::Span Engine::Put(                    \
-        Variable<T>, const size_t, const T &);                                 \
-                                                                               \
+        Variable<T>, const bool, const T &);                                   \
     extern template typename Variable<T>::Span Engine::Put(Variable<T>);       \
     extern template void Engine::Get(Variable<T>, T **) const;
 
